==> kde-workspace-4.10.0.tar.xz: kde-workspace-4.10.0/kdm/kfrontend/sessions/kde-plasma.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${BIN_INSTALL_DIR}/startkde
TryExec=${BIN_INSTALL_DIR}/startkde
Name=KDE Plasma Workspace
Name[ar]=مساحة عمل بلازما كدي
Name[bg]=Работно пространство Plasma на KDE
Name[bn]=কে.ডি.ই. প্লাসমা ওয়ার্কস্পেস
Name[bs]=KDE plasma radni prostor
Name[ca]=Espai de treball del Plasma del KDE
Name[ca@valencia]=Espai de treball del Plasma del KDE
Name[cs]=Pracovní plocha Plasma
Name[da]=KDE Plasma arbejdsområde
Name[de]=KDE-Plasma-Arbeitsbereich
Name[el]=Χώρος εργασίας Plasma KDE
Name[es]=Espacio de trabajo Plasma de KDE
Name[et]=KDE Plasma töötsoon
Name[eu]=KDE Plasma langunea
Name[fi]=KDE Plasma-työtila
Name[fr]=Espace de travail Plasma de KDE
Name[ga]=Spás Oibre KDE Plasma
Name[gl]=Espazo de traballo Plasma de KDE
Name[he]=סביבת עבודה של KDE Plasma
Name[hu]=KDE Plasma munkaterület
Name[ia]=Spatio de labor de Plasma de KDE
Name[is]=KDE Plasma-vinnurými
Name[it]=Spazio di lavoro di KDE Plasma
Name[kk]=KDE Plasma жұмыс орны
Name[km]=តំបន់​ការងារ​ប្លាស្មា​របស់ KDE
Name[ko]=KDE Plasma 작업 공간
Name[lt]=KDE Plasma darbastalio erdvė
Name[lv]=KDE Plasma darba vide
Name[mr]=KDE प्लाज्मा वर्कस्पेस
Name[nb]=KDE Plasma arbeidsflate
Name[nds]=KDE-Arbeitrebeet Plasma
Name[nl]=KDE Plasma-werkruimte
Name[pa]=KDE ਪਲਾਜ਼ਮਾ ਵਰਕਸਪੇਸ
Name[pl]=Przestrzeń robocza plazmy KDE
Name[pt]=Área de Trabalho Plasma do KDE
Name[pt_BR]=Espaço de trabalho do Plasma do KDE
Name[ro]=Spațiu de lucru Plasma KDE
Name[ru]=Рабочий стол Plasma
Name[sk]=KDE pracovná plocha Plasma
Name[sl]=Delovno okolje KDE Plasma
Name[sr]=КДЕ‑ов плазма радни простор
Name[sr@ijekavian]=КДЕ‑ов плазма радни простор
Name[sr@ijekavianlatin]=KDE‑ov plasma radni prostor
Name[sr@latin]=KDE‑ov plasma radni prostor
Name[sv]=KDE Plasma arbetsyta
Name[tr]=KDE Plasma Çalışma Alanı
Name[ug]=ك د ئې(KDE) پلازما خىزمەت بوشلۇقى
Name[uk]=Робочий простір Плазми KDE
Name[vi]=Không gian Plasma KDE
Name[x-test]=xxKDE Plasma Workspacexx
Name[zh_CN]=KDE Plasma 工作空间
Name[zh_TW]=KDE Plasma 工作空間
Comment=The desktop made by KDE
Comment[ar]=سطح المكتب الذي أنتجته كدي
Comment[bg]=Настолна среда KDE
Comment[bn]=কে.ডি.ই.-র তৈরী ডেস্কটপ
Comment[bs]=Desktop napravio KDE
Comment[ca]=L'escriptori creat pel KDE
Comment[ca@valencia]=L'escriptori creat pel KDE
Comment[cs]=Prostředí od KDE
Comment[da]=Skrivebordet fra KDE
Comment[de]=Die von KDE erstellte Arbeitsfläche
Comment[el]=Η επιφάνεια εργασίας δημιουργήθηκε από το KDE
Comment[es]=El escritorio diseñado por KDE
Comment[et]=KDE loodud töölaud
Comment[eu]=KDE-k eginiko mahaigaina
Comment[fi]=KDE:n tekemä työpöytä
Comment[fr]=Le bureau réalisé par KDE
Comment[gl]=O escritorio feito por KDE
Comment[he]=שולחן העבודה של KDE
Comment[hr]=Radna površina koju je napravio KDE
Comment[hu]=A KDE által készített munkaasztal
Comment[ia]=Le scriptorio facite per KDE
Comment[is]=KDE Skjáborð
Comment[it]=Il desktop fatto da KDE
Comment[kk]=KDE үстелі
Comment[km]=ផ្ទៃ​តុ​បាន​បង្កើត​ដោយ KDE
Comment[ko]=KDE에서 만든 데스크톱
Comment[lt]=Darbastalis sukurtas su KDE
Comment[lv]=KDE veidota darbvirsma
Comment[mr]=KDE ने बनवलेला डेस्कटॉप
Comment[nb]=Skrivebordet som KDE laget
Comment[nds]=KDE-Schriefdisch
Comment[nl]=Het bureaublad gemaakt door KDE
Comment[pa]=KDE ਵਲੋਂ ਬਣਾਇਆ ਡੈਸਕਟਾਪ
Comment[pl]=Pulpit stworzony przez KDE
Comment[pt]=O ambiente de trabalho feito pelo KDE
Comment[pt_BR]=O ambiente de trabalho feito pelo KDE
Comment[ro]=Biroul creat de KDE
Comment[ru]=Окружение рабочего стола от команды KDE
Comment[sk]=Pracovná plocha vytvorená KDE
Comment[sl]=Namizno okolje, ki ga je izdelal KDE
Comment[sr]=Радна површ у изведби КДЕ‑а
Comment[sr@ijekavian]=Радна површ у изведби КДЕ‑а
Comment[sr@ijekavianlatin]=Radna površ u izvedbi KDE‑a
Comment[sr@latin]=Radna površ u izvedbi KDE‑a
Comment[sv]=Skrivbordet skapat av KDE
Comment[tr]=KDE tarafınndan oluşturulan masaüstü
Comment[ug]=بۇ ئۈستەلئۈستى KDE دا ياسالغان
Comment[uk]=Стільниця, створена командою KDE
Comment[x-test]=xxThe desktop made by KDExx
Comment[zh_CN]=KDE 制作的桌面
Comment[zh_TW]=KDE 製作的桌面

==> kde-workspace-4.10.2.tar.xz: kde-workspace-4.10.2/kdm/kfrontend/sessions/kde-plasma.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Type=XSession
Exec=${BIN_INSTALL_DIR}/startkde
TryExec=${BIN_INSTALL_DIR}/startkde
Name=KDE Plasma Workspace
Name[ar]=مساحة عمل بلازما كدي
Name[bg]=Работно пространство Plasma на KDE
Name[bn]=কে.ডি.ই. প্লাসমা ওয়ার্কস্পেস
Name[bs]=KDE plasma radni prostor
Name[ca]=Espai de treball del Plasma del KDE
Name[ca@valencia]=Espai de treball del Plasma del KDE
Name[cs]=Pracovní plocha Plasma
Name[da]=KDE Plasma arbejdsområde
Name[de]=KDE-Plasma-Arbeitsbereich
Name[el]=Χώρος εργασίας Plasma KDE
Name[es]=Espacio de trabajo Plasma de KDE
Name[et]=KDE Plasma töötsoon
Name[eu]=KDE Plasma langunea
Name[fi]=KDE Plasma-työtila
Name[fr]=Espace de travail Plasma de KDE
Name[ga]=Spás Oibre KDE Plasma
Name[gl]=Espazo de traballo Plasma de KDE
Name[he]=סביבת עבודה של KDE Plasma
Name[hu]=KDE Plasma munkaterület
Name[ia]=Spatio de labor de Plasma de KDE
Name[is]=KDE Plasma-vinnurými
Name[it]=Spazio di lavoro di KDE Plasma
Name[kk]=KDE Plasma жұмыс орны
Name[km]=តំបន់​ការងារ​ប្លាស្មា​របស់ KDE
Name[ko]=KDE Plasma 작업 공간
Name[lt]=KDE Plasma darbastalio erdvė
Name[lv]=KDE Plasma darba vide
Name[mr]=केडीई प्लाज्मा वर्कस्पेस
Name[nb]=KDE Plasma arbeidsflate
Name[nds]=KDE-Arbeitrebeet Plasma
Name[nl]=KDE Plasma-werkruimte
Name[pa]=KDE ਪਲਾਜ਼ਮਾ ਵਰਕਸਪੇਸ
Name[pl]=Przestrzeń robocza plazmy KDE
Name[pt]=Área de Trabalho Plasma do KDE
Name[pt_BR]=Espaço de trabalho do Plasma do KDE
Name[ro]=Spațiu de lucru Plasma KDE
Name[ru]=Рабочий стол Plasma
Name[sk]=KDE pracovná plocha Plasma
Name[sl]=Delovno okolje KDE Plasma
Name[sr]=КДЕ‑ов плазма радни простор
Name[sr@ijekavian]=КДЕ‑ов плазма радни простор
Name[sr@ijekavianlatin]=KDE‑ov plasma radni prostor
Name[sr@latin]=KDE‑ov plasma radni prostor
Name[sv]=KDE Plasma arbetsyta
Name[tr]=KDE Plasma Çalışma Alanı
Name[ug]=ك د ئې(KDE) پلازما خىزمەت بوشلۇقى
Name[uk]=Робочий простір Плазми KDE
Name[vi]=Không gian Plasma KDE
Name[x-test]=xxKDE Plasma Workspacexx
Name[zh_CN]=KDE Plasma 工作空间
Name[zh_TW]=KDE Plasma 工作空間
Comment=The desktop made by KDE
Comment[ar]=سطح المكتب الذي أنتجته كدي
Comment[bg]=Настолна среда KDE
Comment[bn]=কে.ডি.ই.-র তৈরী ডেস্কটপ
Comment[bs]=Desktop napravio KDE
Comment[ca]=L'escriptori creat pel KDE
Comment[ca@valencia]=L'escriptori creat pel KDE
Comment[cs]=Prostředí od KDE
Comment[da]=Skrivebordet fra KDE
Comment[de]=Die von KDE erstellte Arbeitsfläche
Comment[el]=Η επιφάνεια εργασίας δημιουργήθηκε από το KDE
Comment[es]=El escritorio diseñado por KDE
Comment[et]=KDE loodud töölaud
Comment[eu]=KDE-k eginiko mahaigaina
Comment[fi]=KDE:n tekemä työpöytä
Comment[fr]=Le bureau réalisé par KDE
Comment[gl]=O escritorio feito por KDE
Comment[he]=שולחן העבודה של KDE
Comment[hr]=Radna površina koju je napravio KDE
Comment[hu]=A KDE által készített munkaasztal
Comment[ia]=Le scriptorio facite per KDE
Comment[is]=KDE Skjáborð
Comment[it]=Il desktop fatto da KDE
Comment[kk]=KDE үстелі
Comment[km]=ផ្ទៃ​តុ​បាន​បង្កើត​ដោយ KDE
Comment[ko]=KDE에서 만든 데스크톱
Comment[lt]=Darbastalis sukurtas su KDE
Comment[lv]=KDE veidota darbvirsma
Comment[mr]=केडीई ने बनवलेला डेस्कटॉप
Comment[nb]=Skrivebordet som KDE laget
Comment[nds]=KDE-Schriefdisch
Comment[nl]=Het bureaublad gemaakt door KDE
Comment[pa]=KDE ਵਲੋਂ ਬਣਾਇਆ ਡੈਸਕਟਾਪ
Comment[pl]=Pulpit stworzony przez KDE
Comment[pt]=O ambiente de trabalho feito pelo KDE
Comment[pt_BR]=O ambiente de trabalho feito pelo KDE
Comment[ro]=Biroul creat de KDE
Comment[ru]=Окружение рабочего стола от команды KDE
Comment[sk]=Pracovná plocha vytvorená KDE
Comment[sl]=Namizno okolje, ki ga je izdelal KDE
Comment[sr]=Радна површ у изведби КДЕ‑а
Comment[sr@ijekavian]=Радна површ у изведби КДЕ‑а
Comment[sr@ijekavianlatin]=Radna površ u izvedbi KDE‑a
Comment[sr@latin]=Radna površ u izvedbi KDE‑a
Comment[sv]=Skrivbordet skapat av KDE
Comment[tr]=KDE tarafınndan oluşturulan masaüstü
Comment[ug]=بۇ ئۈستەلئۈستى KDE دا ياسالغان
Comment[uk]=Стільниця, створена командою KDE
Comment[x-test]=xxThe desktop made by KDExx
Comment[zh_CN]=KDE 制作的桌面
Comment[zh_TW]=KDE 製作的桌面
